@@ -1,5 +1,5 @@
 package Parse::SAMGov::Entity::PointOfContact;
-$Parse::SAMGov::Entity::PointOfContact::VERSION = '0.104';
+$Parse::SAMGov::Entity::PointOfContact::VERSION = '0.105';
 use strict;
 use warnings;
 use 5.010;
@@ -34,9 +34,9 @@ use overload
     return $str;
   };
 
-has 'first';
-has 'middle';
-has 'last';
+has 'first' => default => sub { '' };
+has 'middle' => default => sub { '' };
+has 'last' => default => sub { '' };
 has 'title';
 has 'phone';
 has 'phone_ext';
@@ -44,6 +44,14 @@ has 'phone_nonUS';
 has 'fax';
 has 'email' => coerce => sub { Email::Valid->address($_[0]); };
 
+sub name {
+    if (length $_[0]->middle) {
+        return join(' ', $_[0]->first, $_[0]->middle, $_[0]->last);
+    } else {
+        return join(' ', $_[0]->first, $_[0]->last);
+    }
+}
+
 1;
 
 =pod
@@ -56,7 +64,7 @@ Parse::SAMGov::Entity::PointOfContact - Defines the Point of Contact object of t
 
 =head1 VERSION
 
-version 0.104
+version 0.105
 
 =head1 SYNOPSIS
 
@@ -96,6 +104,10 @@ Get/Set the middle initial of the point of contact.
 
 Get/Set the last name of the point of contact.
 
+=head2 name
+
+Get the full name of the point of contact as a string.
+
 =head2 title
 
 Get/Set the title of the point of contact. Example is CEO, President, etc.
